<?php

class Freshmail_Subscription_Helper_Data extends Mage_Core_Helper_Abstract
{
    public $hash;
    public $key;
    public $secret;
    
    public function __construct(){
        $this->hash = Mage::getStoreConfig('subscription/general/subscription_hash');
        $this->key = Mage::getStoreConfig('subscription/general/api_key');
        $this->secret = Mage::getStoreConfig('subscription/general/api_secret');
    }    
    
    /**
     * zapis do loga
     * 
     */
    public function log($data, $filename = 'freshmail.log')
    {
        return Mage::getModel('core/log_adapter', $filename)->log($data);
    }
    
    /**
     * sprawdzenie czy dane wymagane do polaczenia sa ustawione
     * 
     * @return boolen
     */
    public function checkAuth() {
        if(!empty($this->hash) && !empty($this->key) && !empty($this->secret)) {
                return true;
            } else {
                return false;
            }
    }
    
    /**
     * sprawdzenie i ustwienie w razie potrzeby domyslnych custom fields
     * 
     * @return null
     */
    public function checkCustomFields($fm) {
        try {
                //Mage::helper('subscription')->log();
                $customFields = $fm->doRequest('subscribers_list/getFields', array('hash' => $this->hash));
                if(isset($customFields['fields'])) {
                    $fields = $customFields['fields'];
                } else {
                    $fields = null;
                }
                $existingFields = array();
                $testFMA = 0;
                if(is_array($fields)) {
                    foreach ($fields as $field) {
                        if($field['name'] == 'FMA') $testFMA = 1;
                        $existingFields[] = $field['name'];
                    }
                }
    
                if(!$testFMA) {
                    //pole FMA_PLATFORM bedzie przechowywac informacje jaka aplikacja dodala subskrybenta
                    $fm->doRequest('subscribers_list/addField', array('hash' => $this->hash, 'name' => 'FMA_PLATFORM'));
                    
                    //pola domyslnie zdefiniowane w pluginie
                    $fm->doRequest('subscribers_list/addField', array('hash' => $this->hash, 'name' => 'FMA_STORE_ID'));
                    $fm->doRequest('subscribers_list/addField', array('hash' => $this->hash, 'name' => 'FMA_WEBSITE_ID'));
                    $fm->doRequest('subscribers_list/addField', array('hash' => $this->hash, 'name' => 'FMA_CREATED_AT'));
                    $fm->doRequest('subscribers_list/addField', array('hash' => $this->hash, 'name' => 'FMA_CREATED_IN'));
                    $fm->doRequest('subscribers_list/addField', array('hash' => $this->hash, 'name' => 'FMA_GROUP_ID'));
                    $fm->doRequest('subscribers_list/addField', array('hash' => $this->hash, 'name' => 'FMA_DOB'));
                    $fm->doRequest('subscribers_list/addField', array('hash' => $this->hash, 'name' => 'FMA_PREFIX'));
                    $fm->doRequest('subscribers_list/addField', array('hash' => $this->hash, 'name' => 'FMA_FIRSTNAME'));
                    $fm->doRequest('subscribers_list/addField', array('hash' => $this->hash, 'name' => 'FMA_MIDDLENAME'));
                    $fm->doRequest('subscribers_list/addField', array('hash' => $this->hash, 'name' => 'FMA_LASTNAME'));
                    $fm->doRequest('subscribers_list/addField', array('hash' => $this->hash, 'name' => 'FMA_GENDER'));
                    
                    //RFM
                    $fm->doRequest('subscribers_list/addField', array('hash' => $this->hash, 'name' => 'FMA_R'));
                    $fm->doRequest('subscribers_list/addField', array('hash' => $this->hash, 'name' => 'FMA_F'));
                    $fm->doRequest('subscribers_list/addField', array('hash' => $this->hash, 'name' => 'FMA_M'));
                    
                    //informujemy ze stworzylismy wszystkie standardowe pola ustawiajac flage
                    $fm->doRequest('subscribers_list/addField', array('hash' => $this->hash, 'name' => 'FMA', 'field_type' => '1'));
                } else {
                    //tworzymy nowe pola na liscie subskrybcyjnej jesli pojawily sie nowe w magento
                    $mFields = unserialize(Mage::getStoreConfig('subscription/general/custom_fields'));
                    foreach ($mFields as $mfield) {
                        if(!in_array($mfield['freshmail'], $existingFields)) {
                            $fm->doRequest('subscribers_list/addField', array('hash' => $this->hash, 'name' => $mfield['freshmail']));
                        }
                    }
                }
            } catch (exception $e) {
                Mage::helper('subscription')->log( print_r($fm->getErrors(),true));
            }
    }

    /**
     * obliczanie RFM dla danego maila
     * 
     * @return array()
     */
    public function getRFM($email) {
       $rTemp = 0;
       $fTemp = 0;
       $mTemp = 0;
       
       $orders = Mage::getModel('sales/order')->getCollection()
            ->addAttributeToSelect('grand_total')
            ->addAttributeToSelect('created_at')
            ->addAttributeToSort('created_at', 'ASC')
            ->addAttributeToFilter('customer_email',array('eq' => $email))
            ->addAttributeToFilter('created_at',array('from' => date('Y-m-d', strtotime('-3 months'))));
            
        foreach($orders as $val) {
            $mTemp += $val['grand_total'];
            $fTemp ++;
            $rTemp = $val['created_at'];
        }
            $rTemp = strtotime("now") - strtotime($rTemp);
        
        switch(true) {
            case ($mTemp > 0 && $mTemp < 10):
                $m = 1;
            break;
            case ($mTemp >= 10 && $mTemp < 20):
                $m = 2;
            break;
            case ($mTemp >= 20):
                $m = 3;
            break;
            default:
                $m = 0;
            break;
        }
        switch(true) {
            case ($fTemp == 1):
                $f = 1;
            break;
            case ($fTemp == 2 || $fTemp == 3):
                $f = 2;
            break;
            case ($fTemp > 3):
                $f = 3;
            break;
            default:
                $f = 0;
            break;
        }
        switch(true) {
            case ($rTemp < 7862400):
                $r = 1;
            case ($rTemp < 2592000):
                $r = 2;
            case ($rTemp < 604800):
                $r = 3;
            break;
            default:
                $r = 0;
            break;
        }
        return array('r' => $r, 'f' => $f, 'm' => $m);
    }

    /**
     * odwzorowanie status magento na statusy Freshmail
     * 
     * @return integer
     */
    public function getFreshmailStatus($mStatus) {
        switch ($mStatus) {
            case '1':
                $fStatus = 1;
            break;
            case '2':
                $fStatus = 3;
            break;
            case '3':
                $fStatus = 4;
            break;
            case '4':
                $fStatus = 2;
            break;
            default:
                $fStatus = 3;
            break;
        }
        return $fStatus;
    }
}