<?php

/**
 * Events Observer model
 *
 * @category   Freshmail
 * @package    Freshmail_Subscription
 * @author     Freshmail / Grzegorz Gorczyca
 */
class Freshmail_Subscription_Model_Observer
{
    /**
     * metoda trigerowana w momencie zmiany lub dodania subskrybenta
     * 
     * @return null
     */
    public function addEditSubscriber(Varien_Event_Observer $observer) {
        require_once(BP . DS .'lib/Subscription/FmRestApi.php');
        if(Mage::helper('subscription')->checkAuth()) {
            try {
                $subscriber = $observer->getEvent()->getSubscriber();
                $email = $subscriber->getSubscriberEmail();
                $mageStatus = $subscriber->getSubscriberStatus();
                $storeId = $subscriber->getStoreId();
                $cFields = array();
                $customerId = $subscriber->getCustomerId();
                if(!empty($customerId)) {
                    $customer_data = Mage::getModel('customer/customer')->load($customerId);
                    $mFields = unserialize(Mage::getStoreConfig('subscription/general/custom_fields'));
                    
                    $customer_data = $customer_data->get();
                    foreach($mFields as $mField) {
                        $cFields[strtolower($mField['freshmail'])] = $customer_data[$mField['magento']];
                    }
                }
                
                $rfm = Mage::helper('subscription')->getRFM($email);
                $cFields['fma_r'] = $rfm['r'];
                $cFields['fma_f'] = $rfm['f'];
                $cFields['fma_m'] = $rfm['m'];

                $fm = new FmRestApi();
                $fm->setApiKey(Mage::helper('subscription')->key);
                $fm->setApiSecret(Mage::helper('subscription')->secret);
                
                $status = Mage::helper('subscription')->getFreshmailStatus($mageStatus);

                $data = array(
                                'email' => $email,
                                'list'  => Mage::helper('subscription')->hash,
                                'state' => $status,
                                'confirm' => '0',
                                'custom_fields' => $cFields
                                );
                $fm->doRequest('subscriber/add', $data);
                
                Mage::helper('subscription')->log(array('add', $email));
            } catch (exception $e) {
                $errors = $fm->getErrors();
                $edit = 0;
                if (is_array($errors)) {
                    foreach ($errors as $error) {
                        if($error['code'] == 1304 ) $edit = 1;
                    }
                }
                if($edit){
                    try {
                        unset($data['confirm']);
                        $fm->doRequest('subscriber/edit', $data);
                        Mage::helper('subscription')->log(array('edit', $email));
                    } catch (exception $e) {
                        Mage::helper('subscription')->log(array($email, print_r($fm->getErrors(),true)));
                    }
                } else{
                    Mage::helper('subscription')->log(array($email, print_r($fm->getErrors(),true)));
                }
            }
        }
    }
    
    /**
     *metoda trigerowana w momencie usuniecia klienta
     *
     * @return null 
     */
    public function deleteSubscriber(Varien_Event_Observer $observer) {
        require_once(BP . DS .'lib/Subscription/FmRestApi.php');
        if(Mage::helper('subscription')->checkAuth()) {
            try {
                $subscriber = $observer->getEvent()->getSubscriber();
                $email = $subscriber->getSubscriberEmail();
                
                $fm = new FmRestApi();
                $fm->setApiKey(Mage::helper('subscription')->key);
                $fm->setApiSecret(Mage::helper('subscription')->secret);
                $data = array(
                                'email' => $email,
                                'list'  => Mage::helper('subscription')->hash
                             );
                $fm->doRequest('subscriber/delete', $data);
                
                Mage::helper('subscription')->log(array('delete', $email));
            } catch (exception $e) {
                Mage::helper('subscription')->log(array($email, print_r($fm->getErrors(),true)));
            }
        }
    }

    /**
     * metoda trigerowana w momencie edycji danych klienta
     * 
     * @return null
     */
    public function updateCustomer(Varien_Event_Observer $observer) {
        require_once(BP . DS .'lib/Subscription/FmRestApi.php');

        if(Mage::helper('subscription')->checkAuth()) {
            try {
                $customer = $observer->getCustomer();
                $newEmail = $customer->getEmail();
                $oldEmail = $customer->getOrigData('email');

                $mFields = unserialize(Mage::getStoreConfig('subscription/general/custom_fields'));
                $cFields = array();
                $customerFields = $customer->get();
                foreach($mFields as $mField) {
                    $cFields[strtolower($mField['freshmail'])] = $customerFields[$mField['magento']];
                }

                $fm = new FmRestApi();
                $fm->setApiKey(Mage::helper('subscription')->key);
                $fm->setApiSecret(Mage::helper('subscription')->secret);
                
                $rfm = Mage::helper('subscription')->getRFM($oldEmail);
                $cFields['fma_r'] = $rfm['r'];
                $cFields['fma_f'] = $rfm['f'];
                $cFields['fma_m'] = $rfm['m'];
                
                if($newEmail != $oldEmail) {
                    $data = array(
                                'email' => $oldEmail,
                                'list'  => Mage::helper('subscription')->hash
                             );
                    $fm->doRequest('subscriber/delete', $data);
                    Mage::helper('subscription')->log(array('customerDelete', $oldEmail));
                    
                    
                    $data = array(
                                'email' => $newEmail,
                                'list'  => Mage::helper('subscription')->hash,
                                'state' => $status,
                                'confirm' => '0',
                                'custom_fields' => $cFields
                              );
                    $fm->doRequest('subscriber/add', $data);
                    Mage::helper('subscription')->log(array('customerAdd', $newEmail));
                } else {
                    $data = array(
                                'email' => $newEmail,
                                'list'  => Mage::helper('subscription')->hash,
                                'state' => $status,
                                'custom_fields' => $cFields
                              );
                    $fm->doRequest('subscriber/edit', $data);
                    Mage::helper('subscription')->log(array('customerEdit', $newEmail));
                }
            } catch (exception $e) {
                Mage::helper('subscription')->log(array($email, print_r($fm->getErrors(),true)));
            }
        }
    }
} 