<?php
class Freshmail_Subscription_IndexController extends Mage_Core_Controller_Front_Action
{
    public function indexAction()
    {
		$this->loadLayout();     
		$this->renderLayout();
    }

/**
 * zapisywanie do newslettera poprzez popupa
 * 
 * @return array()
 */
    public function popupAction(){
        
        $result = array(
            'status'    => 'error',
            'message'   => 'Zapisanie do newslettera nie powiodło się, prosze spróbować później.' 
            );
        
        $email = $this->getRequest()->getPost('email');

        /*****************sprawdzanie czy podano poprawny adres email*******************/
        if(!preg_match('/^[A-Za-z0-9._%+-]+@[A-Za-z0-9.-]+\.[A-Za-z]{2,4}$/', $this->getRequest()->getPost('email'))) {
            $result = array(
                'status'    => 'error',
                'message'   => 'Podany adres e-mail nie jest prawidłowy.' 
            );
        } else {
            $checkEmail = Mage::getModel('newsletter/subscriber')->loadByEmail($email)->getSubscriberId();
            /*****************sprawdzanie czy podano adres email jest juz zapisany do newslettera*******************/
            if(!empty($checkEmail)){
                $result = array(
                    'status'    => 'error',
                    'message'   => 'Podany adres e-mail jest już zapisany do newslettera.' 
                );
            } else {
                $customerId = Mage::getModel('customer/customer')->setWebsiteId(Mage::app()->getStore()->getWebsiteId())
                                                                ->loadByEmail($email)
                                                                ->getId();
                                                                
                $currentId = Mage::getSingleton('customer/session')->getCustomer()->getId();
                /*****************sprawdzanie czy ktos jest zarejestrowany na podany adres email i czy jest to obecnie zalogowany user*******************/
                if (empty($customerId) || (!empty($customerId) && !empty($currentId) && $customerId == $currentId)) {
                    $subscribe = Mage::getModel('newsletter/subscriber')->subscribe($email);
                    $result = array(
                        'status'    => 'success',
                        'message'   => 'Poprawnie zapisano nowego subskrybenta.'
                    );
                    
                } else {
                    $result = array(
                        'status'    => 'error',
                        'message'   => 'Na podany adres e-mail jest już zarejestrowany inny użytkownik.' 
                    );
                }
            }
        }
        echo json_encode($result);
    }

    /**
     * reczne wywolanie synchronizowanie listy subskrybcyjnej z freshmail
     * 
     * @return array()
     */
    static public function syncAction()
    {
        Mage::helper('subscription')->log('freshmailSync');
        require_once(BP . DS .'lib/Subscription/FmRestApi.php');

        if(Mage::helper('subscription')->checkAuth()) {
            $fm = new FmRestApi();
            $fm->setApiKey(Mage::getStoreConfig('subscription/general/api_key'));
            $fm->setApiSecret(Mage::getStoreConfig('subscription/general/api_secret'));
            
            Mage::helper('subscription')->checkCustomFields($fm);
                
            try {
                $collection = Mage::getModel('newsletter/subscriber')->getCollection();
                foreach ($collection as $item) {
                    $cFields = array();
                    if(!empty($item['customer_id'])) {
                        $customer_data = Mage::getModel('customer/customer')->load($item['customer_id']);
                        $mFields = unserialize(Mage::getStoreConfig('subscription/general/custom_fields'));
                        
                        $customer_data = $customer_data->get();
                        foreach($mFields as $mField) {
                            $cFields[strtolower($mField['freshmail'])] = $customer_data[$mField['magento']];
                        }
                    }
                
                    $rfm = Mage::helper('subscription')->getRFM($item['subscriber_email']);
                    $cFields['fma_r'] = $rfm['r'];
                    $cFields['fma_f'] = $rfm['f'];
                    $cFields['fma_m'] = $rfm['m'];
                
                    $status = Mage::helper('subscription')->getFreshmailStatus($item['subscriber_status']);
                    try {
                        $data = array(
                            'email' => $item['subscriber_email'],
                            'list'  => Mage::helper('subscription')->hash,
                            'custom_fields' => $cFields
                        );
                        $fm->doRequest('subscriber/edit', $data);
                    } catch (exception $e) {
                        $errors = $fm->getErrors();
                        $add = 0;
                        if (is_array($errors)) {
                            foreach ($errors as $error) {
                                if($error['code'] == 1331 ) $add = 1;
                            }
                        }
                        if($add){
                            try {
                                $data['confirm'] = '0';
                                $fm->doRequest('subscriber/add', $data);
                            } catch (exception $e) {
                                Mage::helper('subscription')->log(array($item['subscriber_email'], print_r($fm->getErrors(),true)));
                                continue;
                            }
                        } else{
                            Mage::helper('subscription')->log(array($item['subscriber_email'], print_r($fm->getErrors(),true)));
                            continue;
                        }
                    }
                }
            } catch (exception $e) {
                Mage::helper('subscription')->log(print_r($e,true));
                $result = array(
                        'status'    => 'error',
                        'message'   => 'Nie udało się.' 
                    );
                echo json_encode($result);
            }
        }
                $result = array(
                        'status'    => 'ok',
                        'message'   => 'Udało się.' 
                    );
                echo json_encode($result);
    }


}
